import { Component } from '@angular/core';
import { NavController, ToastController, NavParams } from 'ionic-angular';
import { LoginPage } from '../login/login';
import { AngularFireDatabase } from 'angularfire2/database';
import { AngularFireAuth } from 'angularfire2/auth';
import { DashPlayerPage } from '../dash-player/dash-player';
import { DashDmPage } from '../dash-dm/dash-dm';

@Component({
  selector: 'page-home',
  templateUrl: 'home.html'
})
export class HomePage {

  userID: string;

  constructor(
    public navCtrl: NavController,
    private afDatabase: AngularFireDatabase,
    private afAuth: AngularFireAuth,
    private toast: ToastController,
    public navParams: NavParams
  ) {
    this.afAuth.authState.subscribe(user =>{
      if(user) this.userID=user.uid;
    })
  }

  goToLogin() {
    this.navCtrl.push(LoginPage);
  }

  logOut(){
    this.afAuth.auth.signOut();
    this.toast.create({
      message: 'Logout Succesfully',
      duration:3000
    }).present();
    this.navCtrl.setRoot(LoginPage);
  }

  goToDashPlayer(){
    this.navCtrl.push(DashPlayerPage);
  }

  goToDashDM(){
    this.navCtrl.push(DashDmPage);
  }

  ionViewWillLoad() {
    this.afAuth.authState.take(1).subscribe(data => {
      if (data && data.email && data.uid) {
        this.toast.create({
          message: `Welcome to RolMaster, ${data.email}`,
          duration: 3000
        }).present();

      }
      else {
        this.toast.create({
          message: "Authentication details not found",
          duration: 3000
        }).present();
      }
    })
  }

}
